package cn.com.infosec.asn1;

import cn.com.infosec.util.encoders.Hex;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Enumeration;
import java.util.Vector;

public abstract class ASN1OctetString extends ASN1Object implements ASN1OctetStringParser {
   byte[] string;

   public static ASN1OctetString getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(obj.getObject());
   }

   public static ASN1OctetString getInstance(Object obj) {
      if (obj != null && !(obj instanceof ASN1OctetString)) {
         if (obj instanceof ASN1TaggedObject) {
            return getInstance(((ASN1TaggedObject)obj).getObject());
         } else if (!(obj instanceof ASN1Sequence)) {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         } else {
            Vector var1;
            var1 = new Vector.<init>();
            Enumeration var2 = ((ASN1Sequence)obj).getObjects();

            while(var2.hasMoreElements()) {
               var1.addElement(var2.nextElement());
            }

            return new BERConstructedOctetString(var1);
         }
      } else {
         return (ASN1OctetString)obj;
      }
   }

   public ASN1OctetString(byte[] string) {
      if (string != null) {
         this.string = string;
      } else {
         throw new NullPointerException("string cannot be null");
      }
   }

   public ASN1OctetString(DEREncodable obj) {
      ASN1OctetString var10000 = this;
      super();

      IOException var7;
      label33: {
         ByteArrayOutputStream var8;
         boolean var10001;
         try {
            var8 = new ByteArrayOutputStream;
         } catch (IOException var4) {
            var7 = var4;
            var10001 = false;
            break label33;
         }

         ByteArrayOutputStream var5;
         ByteArrayOutputStream var10002 = var5 = var8;

         DEROutputStream var9;
         try {
            var10002.<init>();
            var9 = new DEROutputStream;
         } catch (IOException var3) {
            var7 = var3;
            var10001 = false;
            break label33;
         }

         DEROutputStream var10003 = var9;
         DEROutputStream var10004 = var9;

         try {
            var10004.<init>(var5);
            var10003.writeObject(obj);
            var9.close();
            var10000.string = var8.toByteArray();
            return;
         } catch (IOException var2) {
            var7 = var2;
            var10001 = false;
         }
      }

      IOException var6 = var7;
      throw new IllegalArgumentException("Error processing object : " + var6.toString());
   }

   public InputStream getOctetStream() {
      return new ByteArrayInputStream(this.string);
   }

   public ASN1OctetStringParser parser() {
      return this;
   }

   public byte[] getOctets() {
      return this.string;
   }

   public int hashCode() {
      byte[] var3 = this.getOctets();
      int var1 = 0;

      for(int var2 = 0; var2 != var3.length; ++var2) {
         var1 ^= (var3[var2] & 255) << var2 % 4;
      }

      return var1;
   }

   boolean asn1Equals(DERObject o) {
      if (!(o instanceof ASN1OctetString)) {
         return false;
      } else {
         byte[] var3 = ((ASN1OctetString)o).string;
         byte[] o1 = this.string;
         if (var3.length != o1.length) {
            return false;
         } else {
            for(int var2 = 0; var2 != var3.length; ++var2) {
               if (var3[var2] != o1[var2]) {
                  return false;
               }
            }

            return true;
         }
      }
   }

   abstract void encode(DEROutputStream var1);

   public String toString() {
      return "#" + new String(Hex.encode(this.string));
   }
}
